%define	name	tclx
%define	version	8.3.5
%define	release	%mkrel 2
%define major	8.3
%define libname	%mklibname %{name} %{major}

Name:		%{name}
Version:	%{version}
Release:	%{release}
Epoch:		0
Summary:	Tcl/Tk extensions for POSIX systems
License:	BSD
Group:		System/Libraries
URL:		http://tclx.sourceforge.net/
Source0:	http://prdownloads.sourceforge.net/tclx/tclx%{version}-src.tar.bz2
Requires:	tcl tk
BuildRequires:	tcl-devel
BuildRequires:	tk-devel
BuildRequires:	groff
Patch0:		tclx-8.3.5-nobuildhelp.patch
Patch1:		tclx-8.3-varinit.patch
Patch2:		tclx-8.3-nonstrip.patch
# avoid tclXtest target which requires .c files from tcl to build
Patch3:		tclx-8.3.5-tcl-mk-skiptest.patch
Patch4:		tclx-8.3.5-clock_t-gcc4.patch
Patch5:		tclx8.3.5-soname.diff
Buildroot:	%{_tmppath}/%{name}-%{version}-buildroot

%description
TclX is a set of extensions which make it easier to use the Tcl
scripting language for common UNIX/Linux programming tasks.  TclX
enhances Tcl support for files, network access, debugging, math, lists,
and message catalogs.  TclX can be used with both Tcl and Tcl/Tk
applications.

Install TclX if you are developing applications with Tcl/Tk.  You'll
also need to install the tcl and tk packages.

%package -n	%{libname}
Summary:	Shared libraries for %{name}
Group:		System/Libraries

%description -n %{libname}
TclX is a set of extensions which make it easier to use the Tcl
scripting language for common UNIX/Linux programming tasks.  TclX
enhances Tcl support for files, network access, debugging, math, lists,
and message catalogs.  TclX can be used with both Tcl and Tcl/Tk
applications.

Install TclX if you are developing applications with Tcl/Tk.  You'll
also need to install the tcl and tk packages.

%package -n	%{libname}-devel 
Summary:	Development files for %{name}
Group:		Development/Other
Requires:	%{libname} = %{epoch}:%{version}
Provides:	%{name}-devel = %{epoch}:%{version}-%{release}
Provides:	lib%{name}-devel = %{epoch}:%{version}-%{release}

%description -n	%{libname}-devel
This package contains development files for %{name}.

%prep

%setup -q -n tclx%{version}
%patch0 -p1 -b .nobuildhelp
%patch1 -p1 -b .varinit
%patch2 -p1 -b .nonstrip
%patch3 -p1 -b .test
%patch4 -p1 -b .clock_t
%patch5 -p1 -b .soname

%build
for f in config.guess config.sub ; do
        test -f /usr/share/libtool/$f || continue
        find . -type f -name $f -exec cp /usr/share/libtool/$f \{\} \;
done

pushd unix

    # setup T(CL|K)X_LIB_SPEC correctly in t(cl|k)xConfig.sh
    export TCLX_INST_LIB=%{_libdir}

    # patch4 touches configure.in
    autoconf-2.13

    # source these (easier)
    . %{_libdir}/tclConfig.sh
    . %{_libdir}/tkConfig.sh

    export SHARED_LIB_SUFFIX="%{major}.so.1"

    %configure \
        --enable-tk=YES \
        --with-tclconfig=%{_libdir} \
        --with-tkconfig=%{_libdir} \
        --with-tclinclude=$TCL_SRC_DIR \
        --with-tkinclude=$TK_SRC_DIR \
	--enable-gcc \
	--enable-shared \
	--enable-64bit

    find . -name 'Common.mk' -exec perl -pi -e 's|-Wl,-rpath,\$\{.*\}||g' {} \;

    # parallell build is borked!
    make

popd

%install
rm -rf %{buildroot}

# utf-8 locale needed to avoid truncating help files
LANG=en_US.UTF-8

make -C unix \
    INSTALL_ROOT=%{buildroot} \
    TCLX_INST_LIB=%{_libdir} \
    TKX_INST_LIB=%{_libdir} \
    TCLX_INST_RUNTIME=%{_datadir}/tclX%{major} \
    TKX_INST_RUNTIME=%{_datadir}/tkX%{major} \
    TCLX_EXEC_RUNTIME=%{_libdir}/tclX%{major} \
    TKX_EXEC_RUNTIME=%{_libdir}/tkX%{major} \
    TCLX_INST_MAN=%{_mandir} \
    install

# fix the shared libname
ln -snf libtclx%{major}.so.1 %{buildroot}%{_libdir}/libtclx%{major}.so
ln -snf libtclx%{major}.so.1 %{buildroot}%{_libdir}/libtclx.so
ln -snf libtkx%{major}.so.1 %{buildroot}%{_libdir}/libtkx%{major}.so
ln -snf libtkx%{major}.so.1 %{buildroot}%{_libdir}/libtkx.so

ln -snf libtclx%{major}.a %{buildroot}%{_libdir}/libtclx.a
ln -snf libtkx%{major}.a %{buildroot}%{_libdir}/libtkx.a

# remove buildroot traces
perl -pi -e "s!$PWD/t(cl|k)/unix!%{_libdir}!" %{buildroot}%{_libdir}/t{cl,k}xConfig.sh

# rename memory.n since tcl-devel also provides it
mv %{buildroot}%{_mandir}/mann/{m,M}emory.n

# (fc) make sure .so files are writable by root
chmod 755 %{buildroot}%{_libdir}/*.so*

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc CHANGES ChangeLog README TO-DO
%attr(0755,root,root) %{_bindir}/*
%{_datadir}/tclX%{major}
%{_datadir}/tkX%{major}
%{_libdir}/tclX%{major}
%{_libdir}/tkX%{major}

%files -n %{libname}
%defattr(-,root,root,-)
%attr(0755,root,root) %{_libdir}/lib*.so.*

%files -n %{libname}-devel
%defattr(-,root,root,-)
%{_includedir}/*.h
%attr(0755,root,root) %{_libdir}/*.so
%attr(0644,root,root) %{_libdir}/*.a
%{_libdir}/tclxConfig.sh
%{_libdir}/tkxConfig.sh
%{_mandir}/man3/*
%{_mandir}/mann/*

%changelog
* Wed Jan 25 2006 Guillaume Rousse <guillomovitch@mandriva.org> 0:8.3.5-2mdk
- introduced epoch for fixing upgrade

* Sun Jan 01 2006 Oden Eriksson <oeriksson@mandriva.com> 8.3.5-1mdk
- initial Mandriva package
- added ideas and patches from fedora
- added soname patch ideas from debian
